.table-container {
    margin: 0px;
    overflow-x: auto;
    position: relative;
}

.table-footer {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 8px 16px;
    margin-top: 0;
}

.table-copy-button {
    display: flex;
    align-items: center;
    margin-left: 16px;
    flex-shrink: 0;
}

/* Copy button reactive icon styles */
.container {
    --color: var(--text-muted);
    --size: 20px;
    display: flex;
    justify-content: center;
    align-items: center;
    position: relative;
    cursor: pointer;
    font-size: var(--size);
    user-select: none;
    fill: var(--color);
    transition: fill 0.2s ease;
}

.container:hover {
    --color: var(--primary);
}

.container .clipboard {
    position: absolute;
    animation: keyframes-fill .5s;
}

.container .clipboard-check {
    position: absolute;
    display: none;
    animation: keyframes-fill .5s;
}

/* On check event */
.container input:checked ~ .clipboard {
    display: none;
}

.container input:checked ~ .clipboard-check {
    display: block;
    --color: var(--primary);
}

/* Hide the default checkbox */
.container input {
    position: absolute;
    opacity: 0;
    cursor: pointer;
    height: 0;
    width: 0;
}

/* Animation */
@keyframes keyframes-fill {
    0% {
        transform: rotate(0deg) scale(0);
        opacity: 0;
    }
    50% {
        transform: rotate(-10deg) scale(1.2);
    }
    100% {
        transform: rotate(0deg) scale(1);
        opacity: 1;
    }
}

.data-table {
    width: 100%;
    border-collapse: collapse;
    background-color: var(--bg);
    box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
    margin: 0;
    font-family: 'Montserrat', sans-serif;
}

.data-table th {
    background-color: var(--bg-dark);
    border: 1px solid var(--border);
    border-top: 0px solid var(--border);
    color: var(--text);
    padding: 12px 16px;
    text-align: left;
}

.data-table td {
    padding: 12px 16px;
    border: 1px solid var(--border);
    color: var(--text);
}

.data-table tr:nth-child(even) {
    background-color: var(--bg);
}

.data-table tr:nth-child(odd) {
    background-color: var(--bg-light);
}

.data-table tr:hover {
    background-color: var(--bg-dark);
    transition: background-color 0.2s ease-in-out;
}

.table-description {
    display: block !important;
    color: var(--text-muted);
    font-size: 0.9rem;
    font-style: italic;
    margin: 0;
    flex-grow: 1;
}

.data-table th:first-child,
.data-table td:first-child {
    border-left: none;
}

.data-table th:last-child,
.data-table td:last-child {
    border-right: none;
}